.. all-saltext.mysql.states:

_____________
State Modules
_____________

.. currentmodule:: saltext.mysql.states

.. autosummary::
    :toctree:

    mysql_database
    mysql_grants
    mysql_query
    mysql_user
